import os

import yaml
from .mongo_log import EasyMongoLog


class EasyMongoConfig:
    host = '127.0.0.1'
    port = 27017
    name = 'name'
    password = 'password'
    logger = EasyMongoLog.logger()

    def __init__(self, yml_path):
        """
        yml config file
        :param yml_path:
        """
        if not os.path.exists(yml_path):
            raise FileNotFoundError('yml config not found')
        # parse
        with open(yml_path, encoding='UTF-8') as f:
            data = f.read()
            conf = yaml.load(data, Loader=yaml.FullLoader)
            self.host = conf['mongo'].get('host')
            self.port = conf['mongo'].get('port')
            self.name = conf['mongo'].get('name')
            self.password = conf['mongo'].get('password')
            self.logger.info('EasyMongoConfig: yml parse done')


if __name__ == "__main__":
    config = EasyMongoConfig('../conf/conf.yml')
    print(config.__dict__)



from pymongo import MongoClient

from .mongo_config import EasyMongoConfig
from .mongo_log import EasyMongoLog


class EasyMongo():
    logger = EasyMongoLog.logger()

    def __init__(self, config_or_yml_path):
        """
        init, require config
        :param config_or_yml_path: yml path or EasyMongoConfig
        """
        if isinstance(config_or_yml_path, EasyMongoConfig):
            self.__config_dic = config_or_yml_path.__dict__
        elif isinstance(config_or_yml_path, str):
            self.__config_dic = EasyMongoConfig(config_or_yml_path).__dict__
        else:
            raise TypeError('config_or_yml_path: need str or EasyMongoConfig')
        self.connect = MongoClient(host=self.__config_dic['host'], port=self.__config_dic['port'])
        self.db = self.connect[self.__config_dic['name']]
        self.db.authenticate(self.__config_dic['name'], self.__config_dic['password'])
        self.logger.info('mongo connected: %s:%d/%s' % (
            self.__config_dic['host'], self.__config_dic['port'], self.__config_dic['name']))

    def get_db(self):
        return self.db

    def get_collection(self, collection: str):
        return self.db[collection]



import logging
import threading


class EasyMongoLog:
    """
    logging, Singleton
    """
    __logger = None
    __instance_lock = threading.Lock()

    @staticmethod
    def logger():
        if EasyMongoLog.__logger is None:
            with EasyMongoLog.__instance_lock:
                if EasyMongoLog.__logger is None:
                    logger = logging.getLogger('easy_mongo_log')
                    logger.setLevel(logging.INFO)
                    # handler, stdout
                    ch = logging.StreamHandler()
                    ch.setLevel(logging.INFO)
                    formatter = logging.Formatter(
                        '[%(asctime)-15s] [%(levelname)s]\t[%(name)s:%(filename)s/%(funcName)s:%(lineno)d]:\t%(message)s')
                    ch.setFormatter(formatter)
                    logger.addHandler(ch)
                    EasyMongoLog.__logger = logger
        return EasyMongoLog.__logger

    @staticmethod
    def info(msg):
        EasyMongoLog.logger().info(msg)



#!/usr/bin/env python
# -*-coding:utf-8-*-
from setuptools import setup, find_packages

setup(
    name='easy_mongo',
    version='0.0.4',
    description=
    'easy to use mongo(kb)',
    long_description=open('README.rst', encoding='utf-8').read(),
    author='ksust',
    author_email='admin@ksust.com',
    maintainer='ksust',
    maintainer_email='admin@ksust.com',
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/ksust/easy_mongo',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    install_requires=[
        'pymongo==3.10.1',
        'PyYAML==5.3.1',
    ]
)
